Node-App API - Shared types and C ABI definitions
This crate provides shared types used by:
- The host backend (NodeAppManager, NativeLoader, BunLoader)
- Native app SDKs (Rust, Go, C, Zig via C ABI)
- Scripted app SDKs (TypeScript/JavaScript via IPC)
Re-exports
pub use context::NodeAppContext;pub use ffi::FfiResult;pub use ffi::NodeAppEntryFn;pub use ffi::NodeAppMetadata;pub use ffi::NodeAppVTable;pub use ffi::NODE_APP_ENTRY_SYMBOL;pub use types::AppEvent;pub use types::AppRequest;pub use types::AppResponse;pub use types::Capabilities;pub use types::CapabilityExample;pub use types::CapabilityRequest;pub use types::CapabilityResponse;pub use types::NodeAppInfo;pub use types::ProvidedCapability;
Modules
- context
- Host context passed to native apps during initialization
- ffi
- C ABI definitions for native app loading
- types
- Shared types used by both native and scripted app loaders
Constants
- API_
VERSION - API version for compatibility checking between host and native apps. Host and app must have matching API_VERSION to load successfully.