Shared types used by both native and scripted app loaders
These types are serialized to JSON for IPC (Bun loader) and converted to/from C representations for FFI (native loader).
Structs
- AppEvent
- Domain event forwarded to apps
- AppRequest
- HTTP request forwarded to an app
- AppResponse
- HTTP response from an app
- Caller
Context - Caller identity injected by the host proxy after JWT validation. Only present on requests that came through the scoped-JWT proxy route. Apps should trust this over any HTTP headers (headers are stripped by the proxy).
- Capabilities
- Capability flags declaring what an app can do
- Capability
Example - An example request payload for a capability.
- Capability
Request - A service capability request dispatched to a provider app. Used for both FFI (serialized as JSON bytes) and IPC (serialized as JSON).
- Capability
Response - Response from a provider app after handling a capability request.
- Node
AppInfo - App metadata returned during initialization
- Provided
Capability - Declaration of a service capability that an app provides. Used in app manifests and registration APIs.